"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAppRouterQuestions = getAppRouterQuestions;
const i18n_1 = require("../i18n");
const types_1 = require("../types");
const validators_1 = require("./validators");
const inquirer_common_1 = require("@sap-ux/inquirer-common");
/**
 * Generates a prompt for selecting the MTA path.
 *
 * @param mtaPath  Mta Path string which allows the user to browse and select a folder for the MTA path
 * @returns {CfAppRouterDeployConfigQuestions} - The prompt configuration object for selecting the MTA path.
 */
function getMtaPathPrompt(mtaPath) {
    return {
        type: 'input',
        guiOptions: {
            type: 'folder-browser',
            breadcrumb: (0, i18n_1.t)('prompts.mtaPathBreadcrumbMessage')
        },
        name: types_1.appRouterPromptNames.mtaPath,
        message: (0, i18n_1.t)('prompts.mtaPathMessage'),
        default: () => mtaPath,
        validate: (input) => (0, validators_1.validateMtaPath)(input)
    };
}
/**
 * Generates a prompt for entering the MTA ID.
 *
 * @returns {CfAppRouterDeployConfigQuestions} - The prompt configuration object for entering the MTA ID.
 */
function getMtaIdPrompt() {
    return {
        type: 'input',
        guiOptions: {
            mandatory: true,
            breadcrumb: true
        },
        name: types_1.appRouterPromptNames.mtaId,
        message: (0, i18n_1.t)('prompts.mtaIdMessage'),
        validate: (input, previousAnswers) => (0, validators_1.validateMtaId)(input, previousAnswers),
        filter: (input) => input.replace(/\./g, '-')
    };
}
/**
 * Generates a prompt for entering the MTA description.
 *
 * @returns {CfAppRouterDeployConfigQuestions} - The prompt configuration object for entering the MTA description.
 */
function getMtaDescriptionPrompt() {
    return {
        type: 'input',
        name: types_1.appRouterPromptNames.mtaDescription,
        guiOptions: {
            breadcrumb: true
        },
        message: (0, i18n_1.t)('prompts.mtaDescriptionMessage'),
        filter: (input) => input?.trim() ?? 'Fiori elements app'
    };
}
/**
 * Generates a prompt for entering the MTA version.
 *
 * @returns {CfAppRouterDeployConfigQuestions} - The prompt configuration object for entering the MTA version.
 */
function getMtaVersionPrompt() {
    return {
        default: '0.0.1',
        name: types_1.appRouterPromptNames.mtaVersion
    };
}
/**
 * Generates a prompt for selecting the router type.
 *
 * This prompt allows users to choose between a standalone app router or a managed app router for deployment.
 * The prompt is mandatory, with a default selection of the "standard" router type.
 *
 * @returns {CfAppRouterDeployConfigQuestions} - The prompt configuration object for selecting the router type.
 */
function getRouterTypePrompt() {
    return {
        type: 'list',
        name: types_1.appRouterPromptNames.routerType,
        guiOptions: {
            mandatory: true,
            breadcrumb: true
        },
        default: () => types_1.RouterModuleType.Standard,
        message: (0, i18n_1.t)('prompts.routerTypeMessage'),
        choices: [
            { name: (0, i18n_1.t)('routerType.standaloneAppRouter'), value: types_1.RouterModuleType.Standard },
            { name: (0, i18n_1.t)('routerType.managedAppRouter'), value: types_1.RouterModuleType.Managed }
        ]
    };
}
/**
 * Generates a prompt for adding a connectivity service.
 *
 * This prompt is shown if the user selects a standalone app router. It asks if the user wants to add a connectivity service,
 * with a default answer of 'false'.
 *
 * @returns {CfAppRouterDeployConfigQuestions} - The prompt configuration object for adding a connectivity service.
 */
function getConnectivityServicePrompt() {
    return {
        when: (previousAnswers) => previousAnswers.routerType !== types_1.RouterModuleType.Managed,
        type: 'confirm',
        name: types_1.appRouterPromptNames.addConnectivityService,
        guiOptions: {
            breadcrumb: (0, i18n_1.t)('prompts.addConnectivityServiceBreadcrumbMessage')
        },
        message: (0, i18n_1.t)('prompts.addConnectivityMessage'),
        default: () => {
            return false;
        }
    };
}
/**
 * Generates a prompt for adding abap service binding
 *
 * This prompt is shown if the user selects a standalone app router. It asks if the user wants to add a destination service,
 * with a default answer of 'false'.
 *
 * @returns {CfAppRouterDeployConfigQuestions} - The prompt configuration object for adding a destination service.
 */
function getDestinationService() {
    return {
        when: (previousAnswers) => previousAnswers.routerType !== types_1.RouterModuleType.Managed,
        type: 'confirm',
        name: types_1.appRouterPromptNames.addABAPServiceBinding,
        message: (0, i18n_1.t)('prompts.serviceAdvancedOptionMessage'),
        default: () => {
            return false;
        }
    };
}
/**
 * Generates a prompt for selecting a service provider from available services.
 *
 * This prompt will be shown if the user chooses to add a destination service and the router type standalone.
 *
 * @returns {CfAppRouterDeployConfigQuestions} - The prompt configuration object for selecting for selecting an ABAP environment service.
 */
function getServiceProvider() {
    const errorHandler = new inquirer_common_1.ErrorHandler();
    return {
        when: (previousAnswers) => {
            return !!previousAnswers.addABAPServiceBinding && previousAnswers.routerType !== types_1.RouterModuleType.Managed;
        },
        type: 'list',
        name: types_1.appRouterPromptNames.abapServiceProvider,
        guiOptions: {
            breadcrumb: (0, i18n_1.t)('prompts.abapEnvBindingBreadcrumbMessage')
        },
        choices: async () => {
            const abapChoices = await (0, inquirer_common_1.getCFAbapInstanceChoices)(errorHandler);
            const choices = [];
            if (abapChoices.length > 0) {
                abapChoices.forEach((choice) => {
                    choices.push({
                        name: choice.name,
                        value: { label: choice.value['label'], service: choice.value['serviceName'] }
                    });
                });
            }
            else {
                choices.push({ name: (0, i18n_1.t)('errors.abapEnvsUnavailable'), value: 'NO_ABAP_ENVS' });
            }
            return choices;
        },
        message: (0, i18n_1.t)('prompts.selectServiceMessage'),
        default: () => (0, i18n_1.t)('errors.abapEnvsUnavailable'),
        validate: (choice) => (0, validators_1.validateAbapService)(choice, errorHandler)
    };
}
/**
 * Retrieves a list of deployment questions based on the application root and prompt options.
 *
 * @param {CfAppRouterDeployConfigPromptOptions} promptOptions - The configuration options for prompting during cf target deployment.
 * @param {Logger} [log] - The logger instance to use for logging.
 * @returns {CfAppRouterDeployConfigQuestions[]} Returns an array of questions related to cf deployment configuration.
 */
async function getAppRouterQuestions(promptOptions, log) {
    const mtaPath = promptOptions[types_1.appRouterPromptNames.mtaPath];
    // add mta path prompt to question array
    const questions = [];
    questions.push(getMtaPathPrompt(mtaPath));
    // Mapping of options
    const questionMapping = [
        { key: types_1.appRouterPromptNames.mtaId, getQuestion: getMtaIdPrompt },
        { key: types_1.appRouterPromptNames.mtaDescription, getQuestion: getMtaDescriptionPrompt },
        { key: types_1.appRouterPromptNames.mtaVersion, getQuestion: getMtaVersionPrompt },
        { key: types_1.appRouterPromptNames.routerType, getQuestion: getRouterTypePrompt },
        {
            key: types_1.appRouterPromptNames.addConnectivityService,
            getQuestion: getConnectivityServicePrompt,
            logMessage: (0, i18n_1.t)('info.addConnectivityService')
        },
        {
            key: types_1.appRouterPromptNames.addABAPServiceBinding,
            getQuestion: getDestinationService,
            logMessage: (0, i18n_1.t)('info.addABAPServiceBinding')
        }
    ];
    // Iterate over the mapping to add questions
    for (const { key, logMessage, getQuestion } of questionMapping) {
        const shouldAddQuestion = promptOptions[key] ?? false;
        if (shouldAddQuestion) {
            if (logMessage) {
                log?.info((0, i18n_1.t)(logMessage));
            }
            questions.push(getQuestion());
        }
    }
    // Add prompts for selecting abap environment if addABAPServiceBinding is true
    if (promptOptions[types_1.appRouterPromptNames.addABAPServiceBinding]) {
        questions.push(getServiceProvider());
    }
    return questions;
}
//# sourceMappingURL=app-router-prompts.js.map